@@ -295,7 +295,7 @@ class MessagesManager(CommonTreeGridManager):
                                                       message=f'<h3>Изменение дела:</h3>#{data_clone.get("guid")}'
                                                               f'<p/>Тема: {data.get("theme__full_name")}'
                                                               f'<p/>{MessagesManager.get_border(data.get("message"), user)}'
-                                                              f'<p/>Cтатус: {Messages_state.objects.get(id=data_clone.get("state_id")).name}'
+                                                              f'<p/>Cтатус: {Messages_state.objects.get(id=data_clone.get("state_id")).name if data_clone.get("state_id") is not None else None}'
                                                               f'<p/>Важность: {Messages_importance.objects.get(id=data_clone.get("importance_id")).name}'
                                                               f'<p/>Изменил: {user.get_short_name}')
 
